@@ -102,7 +102,7 @@ namespace Banshee.Sources.Gui
         private void ConnectEvents ()
         {
             ServiceManager.SourceManager.ActiveSourceChanged += delegate (SourceEventArgs args) {
-                ResetSelection ();
+                Banshee.Base.ThreadAssist.ProxyToMain (ResetSelection);
             };
             
             ServiceManager.SourceManager.SourceUpdated += delegate (SourceEventArgs args) {
@@ -118,10 +118,11 @@ namespace Banshee.Sources.Gui
             };
             
             ServiceManager.PlaybackController.NextSourceChanged += delegate {
-                QueueDraw ();
+                Banshee.Base.ThreadAssist.ProxyToMain (QueueDraw);
             };
             
             notify_stage.ActorStep += delegate (Actor<TreeIter> actor) {
+                Banshee.Base.ThreadAssist.AssertInMainThread ();
                 if (!store.IterIsValid (actor.Target)) {
                     return false;
                 }
@@ -191,6 +192,11 @@ namespace Banshee.Sources.Gui
                 OnPopupMenu ();
                 return true;
             }
+            
+            if (!source.CanActivate) {
+                return false;
+            }
+            
 
             if (press.Button == 1) {
                 if (ServiceManager.SourceManager.ActiveSource != source) {
@@ -439,8 +445,8 @@ namespace Banshee.Sources.Gui
         internal Source NewPlaylistSource {
             get {
                 return new_playlist_source ??
-                    new_playlist_source = new PlaylistSource (Catalog.GetString ("New Playlist"), 
-                        ServiceManager.SourceManager.MusicLibrary.DbId);
+                    (new_playlist_source = new PlaylistSource (Catalog.GetString ("New Playlist"), 
+                        ServiceManager.SourceManager.MusicLibrary));
             }
         }
 
