@@ -133,6 +133,16 @@ namespace Banshee.Dap.Ipod
             Dispose ();
         }
         
+        protected override bool CanHandleDeviceCommand (DeviceCommand command)
+        {
+            try {
+                SafeUri uri = new SafeUri (command.DeviceId);
+                return IpodDevice.MountPoint.StartsWith (uri.LocalPath);
+            } catch {
+                return false;
+            }
+        }
+        
         protected override IDeviceMediaCapabilities MediaCapabilities {
             get { return ipod_device.Parent.MediaCapabilities ?? base.MediaCapabilities; }
         }
@@ -593,8 +603,8 @@ namespace Banshee.Dap.Ipod
                     if (from != null && from.Count > 0) {
                         IPod.Playlist playlist = ipod_device.TrackDatabase.CreatePlaylist (from.Name);
                         foreach (int track_id in ServiceManager.DbConnection.QueryEnumerable<int> (String.Format (
-                            "SELECT CoreTracks.TrackID FROM CoreTracks{0} WHERE {1}",
-                            from.DatabaseTrackModel.JoinFragment, from.DatabaseTrackModel.Condition)))
+                            "SELECT CoreTracks.TrackID FROM {0} WHERE {1}",
+                            from.DatabaseTrackModel.ConditionFromFragment, from.DatabaseTrackModel.Condition)))
                         {
                             playlist.AddTrack (tracks_map[track_id].IpodTrack);
                         }
