@@ -323,6 +323,12 @@ namespace Banshee.Dap.MassStorage
 
 #endregion
 
+        protected override string [] GetIconNames ()
+        {
+            string [] names = ms_device != null ? ms_device.GetIconNames () : null;
+            return names == null ? base.GetIconNames () : names;
+        }
+        
         public override long BytesUsed {
             get { return BytesCapacity - volume.Available; }
         }
@@ -508,7 +514,7 @@ namespace Banshee.Dap.MassStorage
                 
                 // If we are the last track, go ahead and delete the artwork
                 // to ensure that the directory tree can get trimmed away too
-                if (files == 0) {
+                if (files == 0 && CoverArtFileName != null) {
                     System.IO.File.Delete (Paths.Combine (track_dir, CoverArtFileName));
                 }
                 
@@ -531,6 +537,16 @@ namespace Banshee.Dap.MassStorage
                 volume.Eject ();
             }
         }
+        
+        protected override bool CanHandleDeviceCommand (DeviceCommand command)
+        {
+            try {
+                SafeUri uri = new SafeUri (command.DeviceId);
+                return BaseDirectory.StartsWith (uri.LocalPath);
+            } catch {
+                return false;
+            }
+        }
 
         private string GetTrackPath (TrackInfo track, string ext)
         {
